==> mingw-w64-clang-aarch64-flang-18.1.4-1-any.pkg.tar.zst: clangarm64/lib/cmake/flang/FlangTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "FortranCommon" for configuration "Release"
set_property(TARGET FortranCommon APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(FortranCommon PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libFortranCommon.a"
  )

list(APPEND _cmake_import_check_targets FortranCommon )
list(APPEND _cmake_import_check_files_for_FortranCommon "${_IMPORT_PREFIX}/lib/libFortranCommon.a" )

# Import target "FortranEvaluate" for configuration "Release"
set_property(TARGET FortranEvaluate APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(FortranEvaluate PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libFortranEvaluate.a"
  )

list(APPEND _cmake_import_check_targets FortranEvaluate )
list(APPEND _cmake_import_check_files_for_FortranEvaluate "${_IMPORT_PREFIX}/lib/libFortranEvaluate.a" )

# Import target "FortranDecimal" for configuration "Release"
set_property(TARGET FortranDecimal APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(FortranDecimal PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libFortranDecimal.a"
  )

list(APPEND _cmake_import_check_targets FortranDecimal )
list(APPEND _cmake_import_check_files_for_FortranDecimal "${_IMPORT_PREFIX}/lib/libFortranDecimal.a" )

# Import target "FortranLower" for configuration "Release"
set_property(TARGET FortranLower APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(FortranLower PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libFortranLower.a"
  )

list(APPEND _cmake_import_check_targets FortranLower )
list(APPEND _cmake_import_check_files_for_FortranLower "${_IMPORT_PREFIX}/lib/libFortranLower.a" )

# Import target "FortranParser" for configuration "Release"
set_property(TARGET FortranParser APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(FortranParser PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libFortranParser.a"
  )

list(APPEND _cmake_import_check_targets FortranParser )
list(APPEND _cmake_import_check_files_for_FortranParser "${_IMPORT_PREFIX}/lib/libFortranParser.a" )

# Import target "FortranSemantics" for configuration "Release"
set_property(TARGET FortranSemantics APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(FortranSemantics PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libFortranSemantics.a"
  )

list(APPEND _cmake_import_check_targets FortranSemantics )
list(APPEND _cmake_import_check_files_for_FortranSemantics "${_IMPORT_PREFIX}/lib/libFortranSemantics.a" )

# Import target "flangFrontend" for configuration "Release"
set_property(TARGET flangFrontend APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(flangFrontend PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libflangFrontend.a"
  )

list(APPEND _cmake_import_check_targets flangFrontend )
list(APPEND _cmake_import_check_files_for_flangFrontend "${_IMPORT_PREFIX}/lib/libflangFrontend.a" )

# Import target "flangFrontendTool" for configuration "Release"
set_property(TARGET flangFrontendTool APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(flangFrontendTool PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libflangFrontendTool.a"
  )

list(APPEND _cmake_import_check_targets flangFrontendTool )
list(APPEND _cmake_import_check_files_for_flangFrontendTool "${_IMPORT_PREFIX}/lib/libflangFrontendTool.a" )

# Import target "FIRBuilder" for configuration "Release"
set_property(TARGET FIRBuilder APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(FIRBuilder PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libFIRBuilder.a"
  )

list(APPEND _cmake_import_check_targets FIRBuilder )
list(APPEND _cmake_import_check_files_for_FIRBuilder "${_IMPORT_PREFIX}/lib/libFIRBuilder.a" )

# Import target "FIRCodeGen" for configuration "Release"
set_property(TARGET FIRCodeGen APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(FIRCodeGen PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libFIRCodeGen.a"
  )

list(APPEND _cmake_import_check_targets FIRCodeGen )
list(APPEND _cmake_import_check_files_for_FIRCodeGen "${_IMPORT_PREFIX}/lib/libFIRCodeGen.a" )

# Import target "FIRDialectSupport" for configuration "Release"
set_property(TARGET FIRDialectSupport APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(FIRDialectSupport PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libFIRDialectSupport.a"
  )

list(APPEND _cmake_import_check_targets FIRDialectSupport )
list(APPEND _cmake_import_check_files_for_FIRDialectSupport "${_IMPORT_PREFIX}/lib/libFIRDialectSupport.a" )

# Import target "FIRDialect" for configuration "Release"
set_property(TARGET FIRDialect APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(FIRDialect PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libFIRDialect.a"
  )

list(APPEND _cmake_import_check_targets FIRDialect )
list(APPEND _cmake_import_check_files_for_FIRDialect "${_IMPORT_PREFIX}/lib/libFIRDialect.a" )

# Import target "HLFIRDialect" for configuration "Release"
set_property(TARGET HLFIRDialect APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(HLFIRDialect PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libHLFIRDialect.a"
  )

list(APPEND _cmake_import_check_targets HLFIRDialect )
list(APPEND _cmake_import_check_files_for_HLFIRDialect "${_IMPORT_PREFIX}/lib/libHLFIRDialect.a" )

# Import target "HLFIRTransforms" for configuration "Release"
set_property(TARGET HLFIRTransforms APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(HLFIRTransforms PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libHLFIRTransforms.a"
  )

list(APPEND _cmake_import_check_targets HLFIRTransforms )
list(APPEND _cmake_import_check_files_for_HLFIRTransforms "${_IMPORT_PREFIX}/lib/libHLFIRTransforms.a" )

# Import target "FIRSupport" for configuration "Release"
set_property(TARGET FIRSupport APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(FIRSupport PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libFIRSupport.a"
  )

list(APPEND _cmake_import_check_targets FIRSupport )
list(APPEND _cmake_import_check_files_for_FIRSupport "${_IMPORT_PREFIX}/lib/libFIRSupport.a" )

# Import target "FIRTransforms" for configuration "Release"
set_property(TARGET FIRTransforms APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(FIRTransforms PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libFIRTransforms.a"
  )

list(APPEND _cmake_import_check_targets FIRTransforms )
list(APPEND _cmake_import_check_files_for_FIRTransforms "${_IMPORT_PREFIX}/lib/libFIRTransforms.a" )

# Import target "FIRAnalysis" for configuration "Release"
set_property(TARGET FIRAnalysis APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(FIRAnalysis PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libFIRAnalysis.a"
  )

list(APPEND _cmake_import_check_targets FIRAnalysis )
list(APPEND _cmake_import_check_files_for_FIRAnalysis "${_IMPORT_PREFIX}/lib/libFIRAnalysis.a" )

# Import target "bbc" for configuration "Release"
set_property(TARGET bbc APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(bbc PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/bbc.exe"
  )

list(APPEND _cmake_import_check_targets bbc )
list(APPEND _cmake_import_check_files_for_bbc "${_IMPORT_PREFIX}/bin/bbc.exe" )

# Import target "flang" for configuration "Release"
set_property(TARGET flang APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(flang PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/flang.exe"
  )

list(APPEND _cmake_import_check_targets flang )
list(APPEND _cmake_import_check_files_for_flang "${_IMPORT_PREFIX}/bin/flang.exe" )

# Import target "tco" for configuration "Release"
set_property(TARGET tco APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(tco PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/tco.exe"
  )

list(APPEND _cmake_import_check_targets tco )
list(APPEND _cmake_import_check_files_for_tco "${_IMPORT_PREFIX}/bin/tco.exe" )

# Import target "f18-parse-demo" for configuration "Release"
set_property(TARGET f18-parse-demo APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(f18-parse-demo PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/f18-parse-demo.exe"
  )

list(APPEND _cmake_import_check_targets f18-parse-demo )
list(APPEND _cmake_import_check_files_for_f18-parse-demo "${_IMPORT_PREFIX}/bin/f18-parse-demo.exe" )

# Import target "fir-opt" for configuration "Release"
set_property(TARGET fir-opt APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(fir-opt PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/fir-opt.exe"
  )

list(APPEND _cmake_import_check_targets fir-opt )
list(APPEND _cmake_import_check_files_for_fir-opt "${_IMPORT_PREFIX}/bin/fir-opt.exe" )

# Import target "Fortran_main" for configuration "Release"
set_property(TARGET Fortran_main APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Fortran_main PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "C"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libFortran_main.a"
  )

list(APPEND _cmake_import_check_targets Fortran_main )
list(APPEND _cmake_import_check_files_for_Fortran_main "${_IMPORT_PREFIX}/lib/libFortran_main.a" )

# Import target "FortranRuntime" for configuration "Release"
set_property(TARGET FortranRuntime APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(FortranRuntime PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "C;CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libFortranRuntime.a"
  )

list(APPEND _cmake_import_check_targets FortranRuntime )
list(APPEND _cmake_import_check_files_for_FortranRuntime "${_IMPORT_PREFIX}/lib/libFortranRuntime.a" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> mingw-w64-clang-aarch64-flang-19.1.6-1-any.pkg.tar.zst: clangarm64/lib/cmake/flang/FlangTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "FortranCommon" for configuration "Release"
set_property(TARGET FortranCommon APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(FortranCommon PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libFortranCommon.a"
  )

list(APPEND _cmake_import_check_targets FortranCommon )
list(APPEND _cmake_import_check_files_for_FortranCommon "${_IMPORT_PREFIX}/lib/libFortranCommon.a" )

# Import target "FortranEvaluate" for configuration "Release"
set_property(TARGET FortranEvaluate APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(FortranEvaluate PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libFortranEvaluate.a"
  )

list(APPEND _cmake_import_check_targets FortranEvaluate )
list(APPEND _cmake_import_check_files_for_FortranEvaluate "${_IMPORT_PREFIX}/lib/libFortranEvaluate.a" )

# Import target "FortranDecimal" for configuration "Release"
set_property(TARGET FortranDecimal APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(FortranDecimal PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libFortranDecimal.a"
  )

list(APPEND _cmake_import_check_targets FortranDecimal )
list(APPEND _cmake_import_check_files_for_FortranDecimal "${_IMPORT_PREFIX}/lib/libFortranDecimal.a" )

# Import target "FortranLower" for configuration "Release"
set_property(TARGET FortranLower APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(FortranLower PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libFortranLower.a"
  )

list(APPEND _cmake_import_check_targets FortranLower )
list(APPEND _cmake_import_check_files_for_FortranLower "${_IMPORT_PREFIX}/lib/libFortranLower.a" )

# Import target "FortranParser" for configuration "Release"
set_property(TARGET FortranParser APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(FortranParser PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libFortranParser.a"
  )

list(APPEND _cmake_import_check_targets FortranParser )
list(APPEND _cmake_import_check_files_for_FortranParser "${_IMPORT_PREFIX}/lib/libFortranParser.a" )

# Import target "FortranSemantics" for configuration "Release"
set_property(TARGET FortranSemantics APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(FortranSemantics PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libFortranSemantics.a"
  )

list(APPEND _cmake_import_check_targets FortranSemantics )
list(APPEND _cmake_import_check_files_for_FortranSemantics "${_IMPORT_PREFIX}/lib/libFortranSemantics.a" )

# Import target "flangFrontend" for configuration "Release"
set_property(TARGET flangFrontend APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(flangFrontend PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libflangFrontend.a"
  )

list(APPEND _cmake_import_check_targets flangFrontend )
list(APPEND _cmake_import_check_files_for_flangFrontend "${_IMPORT_PREFIX}/lib/libflangFrontend.a" )

# Import target "flangFrontendTool" for configuration "Release"
set_property(TARGET flangFrontendTool APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(flangFrontendTool PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libflangFrontendTool.a"
  )

list(APPEND _cmake_import_check_targets flangFrontendTool )
list(APPEND _cmake_import_check_files_for_flangFrontendTool "${_IMPORT_PREFIX}/lib/libflangFrontendTool.a" )

# Import target "FIRBuilder" for configuration "Release"
set_property(TARGET FIRBuilder APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(FIRBuilder PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libFIRBuilder.a"
  )

list(APPEND _cmake_import_check_targets FIRBuilder )
list(APPEND _cmake_import_check_files_for_FIRBuilder "${_IMPORT_PREFIX}/lib/libFIRBuilder.a" )

# Import target "FIRCodeGen" for configuration "Release"
set_property(TARGET FIRCodeGen APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(FIRCodeGen PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libFIRCodeGen.a"
  )

list(APPEND _cmake_import_check_targets FIRCodeGen )
list(APPEND _cmake_import_check_files_for_FIRCodeGen "${_IMPORT_PREFIX}/lib/libFIRCodeGen.a" )

# Import target "FIRDialectSupport" for configuration "Release"
set_property(TARGET FIRDialectSupport APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(FIRDialectSupport PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libFIRDialectSupport.a"
  )

list(APPEND _cmake_import_check_targets FIRDialectSupport )
list(APPEND _cmake_import_check_files_for_FIRDialectSupport "${_IMPORT_PREFIX}/lib/libFIRDialectSupport.a" )

# Import target "CUFAttrs" for configuration "Release"
set_property(TARGET CUFAttrs APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(CUFAttrs PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libCUFAttrs.a"
  )

list(APPEND _cmake_import_check_targets CUFAttrs )
list(APPEND _cmake_import_check_files_for_CUFAttrs "${_IMPORT_PREFIX}/lib/libCUFAttrs.a" )

# Import target "CUFDialect" for configuration "Release"
set_property(TARGET CUFDialect APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(CUFDialect PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libCUFDialect.a"
  )

list(APPEND _cmake_import_check_targets CUFDialect )
list(APPEND _cmake_import_check_files_for_CUFDialect "${_IMPORT_PREFIX}/lib/libCUFDialect.a" )

# Import target "FIRDialect" for configuration "Release"
set_property(TARGET FIRDialect APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(FIRDialect PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libFIRDialect.a"
  )

list(APPEND _cmake_import_check_targets FIRDialect )
list(APPEND _cmake_import_check_files_for_FIRDialect "${_IMPORT_PREFIX}/lib/libFIRDialect.a" )

# Import target "HLFIRDialect" for configuration "Release"
set_property(TARGET HLFIRDialect APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(HLFIRDialect PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libHLFIRDialect.a"
  )

list(APPEND _cmake_import_check_targets HLFIRDialect )
list(APPEND _cmake_import_check_files_for_HLFIRDialect "${_IMPORT_PREFIX}/lib/libHLFIRDialect.a" )

# Import target "HLFIRTransforms" for configuration "Release"
set_property(TARGET HLFIRTransforms APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(HLFIRTransforms PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libHLFIRTransforms.a"
  )

list(APPEND _cmake_import_check_targets HLFIRTransforms )
list(APPEND _cmake_import_check_files_for_HLFIRTransforms "${_IMPORT_PREFIX}/lib/libHLFIRTransforms.a" )

# Import target "FIRSupport" for configuration "Release"
set_property(TARGET FIRSupport APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(FIRSupport PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libFIRSupport.a"
  )

list(APPEND _cmake_import_check_targets FIRSupport )
list(APPEND _cmake_import_check_files_for_FIRSupport "${_IMPORT_PREFIX}/lib/libFIRSupport.a" )

# Import target "FIRTransforms" for configuration "Release"
set_property(TARGET FIRTransforms APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(FIRTransforms PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libFIRTransforms.a"
  )

list(APPEND _cmake_import_check_targets FIRTransforms )
list(APPEND _cmake_import_check_files_for_FIRTransforms "${_IMPORT_PREFIX}/lib/libFIRTransforms.a" )

# Import target "FIRAnalysis" for configuration "Release"
set_property(TARGET FIRAnalysis APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(FIRAnalysis PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libFIRAnalysis.a"
  )

list(APPEND _cmake_import_check_targets FIRAnalysis )
list(APPEND _cmake_import_check_files_for_FIRAnalysis "${_IMPORT_PREFIX}/lib/libFIRAnalysis.a" )

# Import target "bbc" for configuration "Release"
set_property(TARGET bbc APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(bbc PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/bbc.exe"
  )

list(APPEND _cmake_import_check_targets bbc )
list(APPEND _cmake_import_check_files_for_bbc "${_IMPORT_PREFIX}/bin/bbc.exe" )

# Import target "flang" for configuration "Release"
set_property(TARGET flang APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(flang PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/flang.exe"
  )

list(APPEND _cmake_import_check_targets flang )
list(APPEND _cmake_import_check_files_for_flang "${_IMPORT_PREFIX}/bin/flang.exe" )

# Import target "tco" for configuration "Release"
set_property(TARGET tco APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(tco PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/tco.exe"
  )

list(APPEND _cmake_import_check_targets tco )
list(APPEND _cmake_import_check_files_for_tco "${_IMPORT_PREFIX}/bin/tco.exe" )

# Import target "f18-parse-demo" for configuration "Release"
set_property(TARGET f18-parse-demo APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(f18-parse-demo PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/f18-parse-demo.exe"
  )

list(APPEND _cmake_import_check_targets f18-parse-demo )
list(APPEND _cmake_import_check_files_for_f18-parse-demo "${_IMPORT_PREFIX}/bin/f18-parse-demo.exe" )

# Import target "fir-opt" for configuration "Release"
set_property(TARGET fir-opt APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(fir-opt PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/fir-opt.exe"
  )

list(APPEND _cmake_import_check_targets fir-opt )
list(APPEND _cmake_import_check_files_for_fir-opt "${_IMPORT_PREFIX}/bin/fir-opt.exe" )

# Import target "FortranRuntime" for configuration "Release"
set_property(TARGET FortranRuntime APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(FortranRuntime PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "C;CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libFortranRuntime.a"
  )

list(APPEND _cmake_import_check_targets FortranRuntime )
list(APPEND _cmake_import_check_files_for_FortranRuntime "${_IMPORT_PREFIX}/lib/libFortranRuntime.a" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
